@@ -18,6 +18,26 @@
 
 rm_latest_packages <- function(n = 1, lib = .libPaths()){
 
+  if (!is.numeric(n)) {
+
+    stop(paste0("'n' must be numeric not ", typeof(n)))
+
+  }
+
+  if (!length(n) == 1) {
+
+    stop(paste0("'n' must be of length 1 not ", length(n)))
+
+  }
+
+  if (n < 1) {
+
+    stop(" 'n' must be greater or equal than 1")
+
+  }
+
+
+
   decision <- switch(utils::menu(
     choices = c("NO", "No Way!", "No !!!", "Yes", "Let me think a little bit"),
     title= glue::glue("Removing the last {n} installed packages ?")),
